Соц. сети
=========
Модуль для добавления ссылок на социальные сети.

.. image:: ../_static/soc_networks.png

Поля модели социальных сетей
------------------
    :title: Название
    :icon_ui: Класс иконки
    :icon (upload_to="soc_icon/"): Иконка
    :link: URL cоц. сети